@@ -17,5 +17,19 @@ class TestNoPostcode(unittest.TestCase):
     def testSingleName(self):
         df = pd.DataFrame([['Tom'], ['Bob Jones'], ['Billy-Ray']], columns=['full_name'])
         df = extract_full_name_from_df(df).dropna(subset='surname')
-        #print(df.to_csv())
-        self.assertEqual(1, len(df), f'should have only kept Bob: {df.to_json()}')
\ No newline at end of file
+        self.assertEqual(1, len(df), f'should have only kept Bob: {df.to_json()}')
+
+    def testTitleIsIgnored(self):
+        df = pd.DataFrame([
+            ['Mr Bam Bam Flintstone'],
+            ['Mr. Bam Bam Flintstone'],
+            ['Mrs. Bam Bam Flintstone'],
+            ['Ms. Bam Bam Flintstone'],
+            ['miss Bam Bam Flintstone'],
+            ['dr Bam Bam Flintstone'],
+            ['dr. Bam Bam Flintstone'],
+            ], columns=['full_name'])
+        df = extract_full_name_from_df(df)
+        for _, s in df.iterrows():
+          self.assertEqual('Bam', s['forename'])
+          self.assertEqual('Flintstone', s['surname'])
\ No newline at end of file
