@@ -1,7 +1,21 @@
 # ability to import module from relative path
 import sys; sys.path.insert(0,'./src'); sys.path.insert(0,'../src')
 
-from vipro_python.core.extracts import csv_skip_rows
+from vipro_python.core.extracts import csv_skip_rows, read_extract
+
+# TODO: remove all local excel tests when not on dev machine
+# def test_read_local_excel_xls():
+#   df = read_extract(r'/Users/work/Desktop/pan-essex-nov2023/full-extract-drop/basildon/HousingRegister_20230901.xls')
+#   assert df is not None
+#   assert len(df) > 10
+#   print(f"columns {df.columns}")
+
+# def test_read_local_excel_xlsx():
+#   df = read_extract(r'/Users/work/Desktop/pan-essex-nov2023/full-extract-drop/braintree/Data Matching for Benefits Sep 2023.xlsx')
+#   assert df is not None
+#   assert len(df) > 10
+#   print(f"columns {df.columns}")
+
 
 tests = {
 
